# # Managing Numerical Experiments with SMT
# 
# Suppose we want to run many numerical , how do we manage our experiment and analysis?
# ADCMEKit.jl provides a solution based on [Sumatra](https://github.com/open-research/sumatra).
# 
# When you install ADCMEKit.jl, a custom version of Sumatra is also installed on your system. Therefore, 
# you do not need to install anything manually. 
# 
# Assume that we start a new project `MyProject` (folder name). We use Git for version control. To start a SMT server, 
# in the `MyProject` directory, do 

using ADCMEKit
init_smt()

# Now you can see a `.smt` directory in your folder. 

# Lets create some files. The first file is `test.jl`:

using DelimitedFiles
include("dep.jl")
writedlm("Data/data.txt", ones(10,10)*a)

# The second file is `dep.jl`:

a = 10

# One crucial step is to **commit** your files in the version control system because SMT manages files according to their git version. 
# After that, you can run 

# ```bash 
# $ smt run -m test.jl
# ```

# Here `-m` marks `test.jl` as the main file. We can also do a global configuration 

# ```bash
# $ smt configure -m test.jl 
# ```

# So next time we only need to call `smt run` to run the file. 

# SMT provides a web-based visualization tool to visualize your tasks. To start the web server, do 

# ```bash
# $ smtweb
# ```

# Or in Julia

init_smt_remote()

# Here are some snapshots for the web-based visualization tool. 

# ![](https://github.com/ADCMEMarket/ADCMEImages/blob/master/ADCMEKit/smt1.png?raw=true)
# ![](https://github.com/ADCMEMarket/ADCMEImages/blob/master/ADCMEKit/smt2.png?raw=true)

# **Configurations**

# There are several useful configurations for `smt configure`. 

# ```
# optional arguments:
#   -d PATH, --datapath PATH
#                         set the path to the directory in which smt will search
#                         for datafiles generated by the simulation or analysis.
#   -l OPTION, --addlabel OPTION
#                         If this option is set, smt will append the record
#                         label either to the command line (option 'cmdline') or
#                         to the parameter file (option 'parameters'), and will
#                         add the label to the datapath when searching for
#                         datafiles. It is up to the user to make use of this
#                         label inside their program to ensure files are created
#                         in the appropriate location.
#   -e PATH, --executable PATH
#                         set the path to the executable.
#   -m MAIN, --main MAIN  the name of the script that would be supplied on the
#                         command line if running the simulator normally, e.g.
#                         init.hoc.
# ```




